@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
-
 # Copyright (C) 2006  Joe Wreschnig
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation.
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 """Read and write Ogg bitstreams and pages.
 
@@ -50,7 +50,7 @@ class OggPage(object):
         offset (`int` or `None`): offset this page was read from (default None)
         complete (`bool`): if the last packet on this page is complete
             (default True)
-        packets (List[`bytes`]): list of raw packet data (default [])
+        packets (list[bytes]): list of raw packet data (default [])
 
     Note that if 'complete' is false, the next page's 'continued'
     property must be true (so set both when constructing pages).
@@ -216,7 +216,7 @@ class OggPage(object):
         so also the CRC.
 
         If an error occurs (e.g. non-Ogg data is found), fileobj will
-        be left pointing to the place in the stream the error occured,
+        be left pointing to the place in the stream the error occurred,
         but the invalid data will be left intact (since this function
         does not change the total file size).
         """
@@ -434,7 +434,7 @@ class OggPage(object):
             cls.renumber(fileobj, serial, sequence)
 
     @staticmethod
-    def find_last(fileobj, serial):
+    def find_last(fileobj, serial, finishing=False):
         """Find the last page of the stream 'serial'.
 
         If the file is not multiplexed this function is fast. If it is,
@@ -443,6 +443,10 @@ class OggPage(object):
         This finds the last page in the actual file object, or the last
         page in the stream (with eos set), whichever comes first.
 
+        If finishing is True it returns the last page which contains a packet
+        finishing on it. If there exist pages but none with finishing packets
+        returns None.
+
         Returns None in case no page with the serial exists.
         Raises error in case this isn't a valid ogg stream.
         Raises IOError.
@@ -457,13 +461,17 @@ class OggPage(object):
         except ValueError:
             raise error("unable to find final Ogg header")
         bytesobj = cBytesIO(data[index:])
+
+        def is_valid(page):
+            return not finishing or page.position != -1
+
         best_page = None
         try:
             page = OggPage(bytesobj)
         except error:
             pass
         else:
-            if page.serial == serial:
+            if page.serial == serial and is_valid(page):
                 if page.last:
                     return page
                 else:
@@ -475,12 +483,14 @@ class OggPage(object):
         fileobj.seek(0)
         try:
             page = OggPage(fileobj)
-            while not page.last:
+            while True:
+                if page.serial == serial:
+                    if is_valid(page):
+                        best_page = page
+                    if page.last:
+                        break
                 page = OggPage(fileobj)
-                while page.serial != serial:
-                    page = OggPage(fileobj)
-                best_page = page
-            return page
+            return best_page
         except error:
             return best_page
         except EOFError:
@@ -525,7 +535,7 @@ class OggFileType(FileType):
             raise self._Error("no appropriate stream found")
 
     @loadfile(writable=True)
-    def delete(self, filething):
+    def delete(self, filething=None):
         """delete(filething=None)
 
         Remove tags from a file.
@@ -557,7 +567,7 @@ class OggFileType(FileType):
         raise self._Error
 
     @loadfile(writable=True)
-    def save(self, filething, padding=None):
+    def save(self, filething=None, padding=None):
         """save(filething=None, padding=None)
 
         Save a tag to a file.
@@ -566,7 +576,7 @@ class OggFileType(FileType):
 
         Args:
             filething (filething)
-            padding (PaddingFunction)
+            padding (:obj:`mutagen.PaddingFunction`)
         Raises:
             mutagen.MutagenError
         """
